Learn R Programming

SurvRank (version 0.1)

CVrankSurv_fct: Main function of SurvRank.

Description

Main input function for SurvRank.

Usage

CVrankSurv_fct(data, t.times, cv.out, cv.in, fs.method = "lasso.rank", nr.var = 10, sd1 = 0.95, ncl = 1, weig.t = T, n1 = 0.1, c.time = 10, ...)

Arguments

data
input of data as a list in the format: list.name$x data.frame of covariates. list.name$y response as a survival object, derived from Surv.
t.times
number of times the cross-validation should be repeated
cv.out
number of folds in outer cross validation loop (for estimation of the predictive accuracy)
cv.in
number of folds in inner cross validation loop (for model selection on the training set)
fs.method
Defaults to "lasso.rank". Ranking method to be applied. One of c("lasso.rank","conc.rank","rf.rank","boost.rank","cox.rank","rpart.rank","randcox.rank","wang.rank")
nr.var
Number of variables up to which stepwise selection should be carried out. Has to be smaller than n number of observations.
sd1
factor to which sparser solutions should be chosen. Not maximum Survival AUC in inner loop is used in stepwise selection, instead max(survAUC)*sd1 leading to sparser solutions
ncl
Defaults to 1. Number of clusters for parallel execution.
weig.t
Defaults to TRUE. Should a weighting of features be performed.
n1
used in weighting function if weig.t=T. Find details in weighting_fct
c.time
as defined in package survAUC time; a positive number restricting the upper limit of the time range under consideration.
...
arguments that can be passed to underlying functions, not used now

Value

Output of the CVrankSurv_fct, basically a list containing the following elements
method
ranking method
accuracy$ranking
full ranking of all model estimations
accuracy$pred.in
averaged inner AUCs of stepwise selection
accuracy$pred.out
predictions of testset
accuracy$used.rank
only used features according to stepwise selection
accuracy$used.rank1se
only used features according to stepwise selection with factor sd1
accuracy$auc.out
matrix of dimension cv.out times t.times of survival AUCs.
accuracy$auc.out1se
matrix of dimension cv.out times t.times of survival AUCs with factor sd1.
rank.mat
matrix of ranks per feature. If not selected, it is set to number of features.
out.mat
0/1 matrix for features selected
out.mat1se
0/1 matrix for features selected with factor sd1 application
top1se
unweighted toplist with factor sd1
toplist
unweighted toplist
weighted
weighted toplist with applied weighting function
rank
toplist of ranked features according to ranks

Details

details to follow

Examples

Run this code
## Simulating a survival data set
N=100; p=10; n=4
x=data.frame(matrix(rnorm(N*p),nrow=N,p))
beta=rnorm(n)
mx=matrix(rnorm(N*n),N,n)
fx=mx[,seq(n)]%*%beta/3
hx=exp(fx)
ty=rexp(N,hx)
tcens=1-rbinom(n=N,prob=.3,size=1)
y=Surv(ty,tcens)
data=list()
data$x<-x; data$y<-y
## Ranking the features according to their significance in the univariate cox models
out.cox<-CVrankSurv_fct(data,2,3,3,fs.method="cox.rank")
## Ranking the features according to the LASSO algorithm
## Not run: 
# out.lasso<-CVrankSurv_fct(data,2,5,5,fs.method="lasso.rank")## End(Not run)

Run the code above in your browser using DataLab