Learn R Programming

SurvRank (version 0.1)

fin_surv_model_fct: Building the final survRank model

Description

This function builds the final survRank model

Usage

fin_surv_model_fct(f, data, cv.out, nr.var = 10, c.time = NA)

Arguments

f
ranking approach function. One of fsSurvRankConc, fsSurvRankGlmnet, fsSurvRankRf, fsSurvRankBoost, fsSurvRankCox, fsSurvRankRandCox, fsSurvRankRpart, fsSurvRankWang, fsSurvRankitBMA or NA, no calculation
data
same list used as input in CVrankSurv_fct
cv.out
number of folds in outer cross validation loop (for estimation of the predictive accuracy)
nr.var
Number of variables up to which stepwise selection should be carried out. Has to be smaller than n number of observations.
c.time
as defined in UnoCsurvAUC time; a positive number restricting the upper limit of the time range under consideration

Value

Output of the riskscore_fct, basically a list containing the following elements
ranking
ranking of the variables in the data set using the ranking apporach function
used.rank
variables used in the survRank model according to the number of parameters to be used
model
cox regression model for the selected features
sum.model
summary of the fitted cox model

Details

details to follow