Learn R Programming

SurvRank (version 0.1)

fsRankMonsterAUC_fct: Wrapper function using cox models with randomly selected nmax variables as ranking method

Description

This wrapper function passes the ranking method to further functions. Setting up for parallel computing of different folds via foreach.

Usage

fsRankMonsterAUC_fct(data, fold, ncl, cv.out, cv.in, nr.var, t = 1, sd1 = 0.9, c.time, ...)

Arguments

...
other arguments, not used now
input
see details in CVrankSurv_fct